Retrospective buffer for capturing shell command output.
The buffer allows users to retroactively save commands they didn’t explicitly
capture with shq run. Shell hooks write output to the buffer, and users can
promote entries to permanent storage with shq save ~N.
Structs
- Buffer
- Manager for the retrospective buffer.
- Buffer
Entry - A buffer entry with metadata and output path.
- Buffer
Meta - Metadata for a buffer entry.