Context detection for metadata population.
This module detects VCS (git) and CI environment context to populate metadata fields on invocations.
Structs
- Context
Metadata - Collected context metadata.
Context detection for metadata population.
This module detects VCS (git) and CI environment context to populate metadata fields on invocations.