Project detection for BIRD.
Finds project-level .bird/ directories by walking up from the current directory.
Structs
- Project
Info - Result of project detection.
Constants
- BIRD_
DB_ NAME - The name of the project database file.
- BIRD_
DIR_ NAME - The name of the BIRD project directory.
Functions
- find_
current_ project - Find project from current working directory.
- find_
project - Find the project root by walking up from the given directory.
- is_
in_ project - Check if a directory is inside a BIRD project.
- project_
relative_ path - Get the relative path from project root to the given path.