RangeSelector

Struct RangeSelector 

pub struct RangeSelector {
    pub start: usize,
    pub end: Option<usize>,
}
Range selector for limiting results.

Uses git-style positional semantics:

  • ~N = single item at position N (1 = most recent)
  • ~N: = range from position N to now (last N items)
  • ~N:~M = range from position N to position M

Fields

start: usize

Start position from most recent (1 = most recent, 2 = second most recent)

end: Option<usize>

End position: None = single item, Some(0) = open range to now, Some(N) = to position N

Implementations

Source

impl RangeSelector

pub fn is_single(&self) -> bool

Returns true if this selects a single item (no range).

pub fn is_last_n(&self) -> bool

Returns true if this is an open range to now (last N items).

pub fn last_n_count(&self) -> Option<usize>

Returns the count of items if this is a “last N” range.