pub struct CompactOptions {
pub file_threshold: usize,
pub recompact_threshold: usize,
pub consolidate: bool,
pub dry_run: bool,
pub session_filter: Option<String>,
}Expand description
Options for compaction operations.
Fields
file_threshold: usizeCompact when a session has more than this many non-compacted files.
recompact_threshold: usizeRe-compact when a session has more than this many compacted files. Set to 0 to disable re-compaction.
consolidate: boolIf true, consolidate ALL files (including compacted) into a single file.
dry_run: boolIf true, don’t actually make changes.
session_filter: Option<String>If set, only compact files for this specific session.